@@ -4,7 +4,6 @@ from sym.cli.helpers.sym_group import SymGroup
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
 from .integrations_list import integrations_list
-from .slack import slack_commands
 
 
 @click.group(cls=SymGroup, short_help="Perform operations on Sym Integrations")
@@ -18,4 +17,3 @@ def integrations(options: GlobalOptions) -> None:
 
 
 integrations.add_command(integrations_list)
-integrations.add_command(slack_commands)
