@@ -1,4 +1,5 @@
 import click
+import requests
 import validators
 
 from sym.flow.cli.errors import SymAPIUnknownError
@@ -34,9 +35,20 @@ def validate_email(ctx, param, value):
 def login(options: GlobalOptions, browser: bool, port: int, email: str) -> None:
     api_service = SymAPIService(api_client=SymAPIClient(url=options.api_url))
     org = api_service.get_organization_from_email(email)
-    click.echo("Successfully loaded org: {slug} ({client_id})".format(**org))
+    click.echo("Found org: {slug} ({client_id})\n".format(**org))
 
-    auth_token = LoginFlow.get_login_flow(email, browser, port).login(options, org)
+    flow = LoginFlow.get_login_flow(email, browser, port)
+
+    if browser:
+        (url, *_) = flow.gen_browser_login_params(options, org)
+        styled_url = click.style(requests.utils.requote_uri(url), fg="white", bold=True)
+        click.echo(
+            f"Attempting to open the SSO authorization page in your default browser.\n"
+            f"If the browser doesn't open or you want to use a different device, open the following URL:\n"
+            f"\n{styled_url}\n"
+        )
+
+    auth_token = flow.login(options, org)
     api_service.set_access_token(auth_token.get("access_token"))
     fail_msg = "Sym could not verify this login. Please try again, or visit https://docs.symops.com/docs/login-sym-flow for more details."
 
