@@ -91,6 +91,7 @@ class BrowserRedirectFlow(LoginFlow):
 
     def __init__(self, port: int):
         self.port = port
+        self.browser_login_params = None
 
     def login(self, options: GlobalOptions, org: Organization) -> AuthToken:
         auth_code, code_verifier = self.get_auth_code(options, org)
@@ -124,6 +125,32 @@ class BrowserRedirectFlow(LoginFlow):
     def gen_state(self) -> str:
         return str(uuid.uuid4())
 
+    def gen_browser_login_params(
+        self, options: GlobalOptions, org: Organization, force: bool = False
+    ) -> str:
+        if force or self.browser_login_params is None:
+            scopes_str = " ".join(DEFAULT_SCOPES)
+            state = self.gen_state()
+            code_verifier = pkce.generate_code_verifier(length=128)
+            code_challenge = pkce.get_code_challenge(code_verifier)
+            query_params = "&".join(
+                [
+                    "response_type=code",
+                    f"client_id={org['client_id']}",
+                    "code_challenge_method=S256",
+                    f"code_challenge={code_challenge}",
+                    f"redirect_uri={self.redirect_url}",
+                    f"scope={scopes_str}",
+                    f"audience=https://api.symops.com",
+                    f"state={state}",
+                    "prompt=login",
+                ]
+            )
+            url = f"{options.auth_url}/authorize?{query_params}"
+            self.browser_login_params = (url, state, code_verifier)
+
+        return self.browser_login_params
+
     def get_auth_code(self, options: GlobalOptions, org: Organization) -> Tuple[str, str]:
         """
         Perform the Auth0 code flow by opening the browser with a URL containing query parameters
@@ -133,24 +160,7 @@ class BrowserRedirectFlow(LoginFlow):
         Returns an auth code and a PKCE code verifier that both need to be provided to the
         token endpoint when obtaining an auth token.
         """
-        scopes_str = " ".join(DEFAULT_SCOPES)
-        state = self.gen_state()
-        code_verifier = pkce.generate_code_verifier(length=128)
-        code_challenge = pkce.get_code_challenge(code_verifier)
-        query_params = "&".join(
-            [
-                "response_type=code",
-                f"client_id={org['client_id']}",
-                "code_challenge_method=S256",
-                f"code_challenge={code_challenge}",
-                f"redirect_uri={self.redirect_url}",
-                f"scope={scopes_str}",
-                f"audience=https://api.symops.com",
-                f"state={state}",
-                "prompt=login",
-            ]
-        )
-        url = f"{options.auth_url}/authorize?{query_params}"
+        (url, state, code_verifier) = self.gen_browser_login_params(options, org)
 
         webbrowser.open(url)
 
