@@ -1,16 +1,13 @@
 from datetime import datetime
+from typing import Iterator
 from unittest.mock import ANY, patch
 from urllib.parse import quote
 
 import pytest
 
-from sym.flow.cli.errors import (
-    NotAuthorizedError,
-    SymAPIRequestError,
-    SymAPIUnknownError,
-    UnknownOrgError,
-)
+from sym.flow.cli.errors import NotAuthorizedError, SymAPIRequestError, SymAPIUnknownError
 from sym.flow.cli.helpers.sym_api_client import SymAPIClient
+from sym.flow.cli.helpers.sym_api_service import ConnectorType
 from sym.flow.cli.tests.conftest import get_mock_response
 
 MOCK_INTEGRATIONS_BAD_DATA = [
@@ -37,9 +34,43 @@ MOCK_INTEGRATIONS_DATA = [
     },
 ]
 
+MOCK_SLACK_CONNECTOR_DATA = [
+    {
+        "type_name": "slack",
+        "settings": {
+            "team_name": "connector 1",
+            "team_id": "T1234567",
+            "another_setting": "heyooo",
+        },
+    },
+    {
+        "type_name": "slack",
+        "settings": {
+            "team_name": "connector 2",
+            "team_id": "T7654321",
+            "another_setting": "porcupines",
+        },
+    },
+]
+
+MOCK_SLACK_CONNECTOR_BAD_DATA = [
+    {
+        "type_name": "slack",
+        "settings": {
+            "team_id": "T1234567",
+        },
+    },
+    {
+        "type_name": "slack",
+        "settings": {
+            "team_name": "connector 2",
+        },
+    },
+]
+
 
 @pytest.fixture
-def sym_api_client(sandbox) -> SymAPIClient:
+def sym_api_client(sandbox) -> Iterator[SymAPIClient]:
     with sandbox.push_xdg_config_home():
         yield SymAPIClient(url="http://faketest.symops.io/api/v1")
 
@@ -136,6 +167,18 @@ class TestSymAPIClient:
             )
         mock_api_get.assert_called_once_with(f"login/verify/{quote('test@symops.io')}")
 
+    @patch(
+        "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get",
+        return_value=(
+            get_mock_response(200, data=MOCK_SLACK_CONNECTOR_DATA),
+            "test-request-id",
+        ),
+    )
+    def test_get_connectors(self, mock_api_get, sym_api_client):
+        data, request_id = sym_api_client.get_connectors(ConnectorType.SLACK.value)
+        assert request_id == "test-request-id"
+        assert data == MOCK_SLACK_CONNECTOR_DATA
+
     @patch(
         "sym.flow.cli.helpers.sym_api_client.SymAPIClient.get",
         return_value=(
@@ -175,10 +218,8 @@ class TestSymAPIClient:
         ),
     )
     def test_get_slack_install_url(self, mock_api_get, sym_api_client):
-        url, request_id = sym_api_client.get_slack_install_url(integration_name="12345")
-        mock_api_get.assert_called_once_with(
-            "install/slack", params={"integration_name": "12345"}
-        )
+        url, request_id = sym_api_client.get_slack_install_url()
+        mock_api_get.assert_called_once_with("install/slack/link")
         assert url == "http://hello.sym.com"
         assert request_id == "test-request-id"
 
@@ -188,8 +229,8 @@ class TestSymAPIClient:
     )
     def test_uninstall_slack(self, mock_api_get, sym_api_client):
         assert (
-            sym_api_client.uninstall_slack(integration_name="12345") == "test-request-id"
+            sym_api_client.uninstall_slack(workspace_id="T1234567") == "test-request-id"
         )
         mock_api_get.assert_called_once_with(
-            "uninstall/slack", params={"integration_name": "12345"}
+            "uninstall/slack", params={"team_id": "T1234567"}
         )
